@@ -15,6 +15,7 @@ use IWL::Combo;
 use IWL::Comment;
 use IWL::Container;
 use IWL::Contentbox;
+use IWL::Druid::Page;
 use IWL::Druid;
 use IWL::Entry;
 use IWL::File;
@@ -60,7 +61,7 @@ use IWL::Upload;
 
 use vars qw($VERSION);
 
-$VERSION = '0.46';
+$VERSION = '0.47';
 
 1;
 
@@ -70,7 +71,7 @@ IWL - A widget library for the web
 
 =head1 VERSION
 
-This documentation refers to B<IWL> version 0.45
+This documentation refers to B<IWL> version 0.47
 
 =head1 SYNOPSIS
 
@@ -175,7 +176,7 @@ The following widgets have so far been written. They have extensive documentatio
 
 Configuration is done by editing the I<iwl.conf> file. It can be placed in the directory of the scripts that use IWL, or it's full path and name can be fiven in the I<IWL_CONFIG_FILE> environment variable. A default configuration is provided inside IWL::Config(3pm). See IWL::Config(3pm) for more details
 
-In order to actually use the library, the javascript and css files will also have to be installed in the server's document root. To do that, the 'iwl-install' script is provided. It is usually located in '/usr/bin'. The script also creates a I<iwl.conf> file from the user input.
+In order to actually use the library, the javascript and css files will also have to be installed in the server's document root. To do that, the I<iwl-install> script is provided. It is usually located in '/usr/bin'. The script also creates a I<iwl.conf> file from the user input.
 
 
 =head1 DEPENDENCIES
@@ -185,13 +186,10 @@ In order to actually use the library, the javascript and css files will also hav
   Locale::Messages
   Locale::TextDomain
   HTML::Parser
+  Cwd
 
 =head1 TODO
 
-=head2 General
-
- - Write more testcases
-
 =head2 Perl
 
  - Add more stock items to IWL::Stock
