@@ -5,7 +5,7 @@ package IWL::Iconbox::Icon;
 
 use strict;
 
-use base qw(IWL::Container IWL::RPC::Request);
+use base qw(IWL::Container);
 
 use IWL::Image;
 use IWL::Label;
@@ -33,6 +33,28 @@ Where B<%ARGS> is an optional hash parameter with with key-value options. These
   direction: the direction in which the icon will float in the iconbox
   margin: the margin around the icon. Defaults to '5px'
 
+=head1 SIGNALS
+
+=over 4
+
+=item B<select>
+
+Fires when the icon is selected
+
+=item B<unselect>
+
+Fires when the icon is unselected
+
+=item B<remove>
+
+Fires when the icon is removed
+
+=item B<activate>
+
+Fires when the icon is activated
+
+=back
+
 =cut
 
 sub new {
@@ -54,15 +76,28 @@ sub new {
 
 Sets the image of the icon to the one provided 
 
-Parameters: B<IMAGE> - the location of the image, B<ALT> - the alt text of the image
+Parameters: B<IMAGE> - the url, or the stock id of the image, B<ALT> - the alt text of the image
 
 =cut
 
 sub setImage {
     my ($self, $src, $alt) = @_;
 
+    $src = IWL::Stock->new()->getSmallImage($src) if
+      defined $src && $src =~ /^IWL_STOCK_/;
     $self->{image}->setAlt($alt);
-    return $self->{image}->set($src);
+    $self->{image}->set($src);
+    return $self;
+}
+
+=item B<getImage>
+
+Returns the icon image
+
+=cut
+
+sub getImage {
+    return shift->{image};
 }
 
 =item B<setText> (B<TEXT>)
@@ -80,6 +115,16 @@ sub setText {
     return $self;
 }
 
+=item B<getText>
+
+Returns the text of the icon label
+
+=cut
+
+sub getText {
+    return shift->{__label}->getText;
+}
+
 =item B<setSelected> (B<BOOL>)
 
 Sets whether the icon should be selected.
@@ -91,14 +136,20 @@ Parameters: B<BOOL> - true if the icon should be selected;
 sub setSelected {
     my ($self, $bool) = @_;
 
-    if ($bool) {
-	$self->{_selected} = 1;
-    } else {
-	$self->{_selected} = 0;
-    }
+    $self->{_selected} = $bool ? 1 : 0;
     return $self;
 }
 
+=item B<isSelected>
+
+Returns true if the icon is selected
+
+=cut
+
+sub isSelected {
+    return !(!shift->{_selected});
+}
+
 =item B<setDimensions> (B<WIDTH>, [B<HEIGHT>])
 
 Sets the dimensions of the icon to the given ones.
@@ -112,17 +163,21 @@ Note: the dimension units should be provided. Thus, the above parameters will be
 sub setDimensions {
     my ($self, $width, $height) = @_;
 
-    #    if ($height) {
-    #        $self->{image}->setStyle(height => $height, width => $width);
-    #    } else {
-    #        $self->{image}->setStyle(width => $width);
-    #    }
+    $self->{image}->setStyle(height  => $height) if $height;
     $self->{__label}->setStyle(width => $width);
-    return $self->setStyle(width    => $width);
+    return $self->setStyle(width     => $width);
 }
 
 # Overrides
 #
+sub setId {
+    my ($self, $id) = @_;
+
+    $self->{image}->setId($id . '_image');
+    $self->{__label}->setId($id . '_label');
+    return $self->SUPER::setId($id);
+}
+
 sub signalConnect {
     my ($self, $signal, $callback) = @_;
     if ($signal eq 'load') {
@@ -163,10 +218,10 @@ sub __init {
 
     $args{id} ||= randomize($self->{_defaultClass});
 
-    $self->setStyle(margin => $args{margin} || '5px');
     $self->setStyle(float => $args{direction}) if $args{direction};
+    $self->{image}{_defaultClass} = "icon_image";
     $self->{__label}->{_defaultClass} = "icon_label";
-    delete @args{qw(margin direction)};
+    delete @args{qw(direction)};
 
     $self->appendChild($self->{image});
     $self->appendChild($self->{__label});
