@@ -88,25 +88,25 @@ Object.extend(Event, {
 	});
       }
     }
-    return element;
+    return Event;
   },
   prepareEvents: function(element) {
     if (!(element = $(element))) return;
     if (element.preparedEvents) return element;
     var events = element.readAttribute('iwl:RPCEvents');
     if (events) {
-      events = decodeURIComponent(events).evalJSON();
+      events = unescape(events).evalJSON();
       for (var name in events)
 	Event.registerEvent(element, name, events[name][0], events[name][1]);
       element.preparedEvents = true;
-      return element;
+      return Event;
     }
   },
   emitEvent: function(element, eventName, params) {
     if (!(element = $(element))) return;
     if (!('handlers' in element) || !(eventName in element['handlers'])) return;
     element['handlers'][eventName](params);
-    return element;
+    return Event;
   },
   /* ================================================ */
           
@@ -285,18 +285,29 @@ var ElementMethods = {
     Element.classNames(element).change(oldClassName, newClassName);
     return element;
   },
+  getScrollableParent: function(element) {
+    if (!(element = $(element))) return;
+    do {
+      var dims = element.getDimensions();
+      var scroll = {width: element.scrollWidth, height: element.scrollHeight};
+      if (dims.width != scroll.width || dims.height != scroll.height)
+	break;
+      element = element.up();
+    } while (element);
+    return element;
+  },
   /* = IWL RPC ======================================*/
   registerEvent: function(element, eventName, url, params) {
-    Event.registerEvent.apply(Event, arguments);
-    return $A(arguments).first();        
+    if (Event.registerEvent.apply(Event, arguments))
+      return $A(arguments).first();        
   },
   prepareEvents: function(element) {
-    Event.prepareEvents.apply(Event, arguments);
-    return $A(arguments).first();       
+    if (Event.prepareEvents.apply(Event, arguments))
+      return $A(arguments).first();       
   },
   emitEvent: function(element, eventName, params) {
-    Event.emitEvent.apply(Event, arguments);
-    return $A(arguments).first();  
+    if (Event.emitEvent.apply(Event, arguments))
+      return $A(arguments).first();  
   },
   /*==================================================*/
 
